#!/usr/bin/perl

# Print to stdout a pair of quantities, formatted for tmux (i.e. it
# contains things like '#[fg=white]').  The quantities are the down
# and up network rates through the named interface.

# ©Copyright <webmaster@acrasis.net>. This is free software; you may
# redistribute it and/or modify it under the same terms as Perl
# itself.

use English qw(-no_match_vars);
use common::sense;
use File::Slurp;
use Number::Format;

my $iface = "eth0";
my ($file_dn, $file_up) = (
   "/sys/class/net/$iface/statistics/rx_bytes",
   "/sys/class/net/$iface/statistics/tx_bytes",
);

my $bdn0 = read_file($file_dn);
my $bup0 = read_file($file_up);
sleep(1.0);
my $bdn1 = read_file($file_dn);
my $bup1 = read_file($file_up);

my ($rtdn, $rtup) = ($bdn1 - $bdn0, $bup1 - $bup0);

my $f = Number::Format->new(
   DECIMAL_DIGITS => 1,
   DECIMAL_FILL => 1,
   KIBI_SUFFIX => 'K/s',
   MEBI_SUFFIX => 'M/s'
);

sub form_bytes {
   my ($n, $arrow) = @_;
   # The formatter suitable for KiB and MiB will also put decimals for
   # bytes, which is silly so we format bytes ourselves.
   if ($n < 1024) {
      return sprintf("#[fg=white]%9s%-2s", "${n}B/s", $arrow);
   } else {
      my $rate = sprintf("%9s", $f->format_bytes($n, mode => "iec60027"));
      if ($n < 1_048_576) {
         return sprintf("#[fg=yellow]%9s%-2s", $rate, $arrow);
      } else {
         return sprintf("#[fg=brightcyan,bold]%9s%-2s", $rate, $arrow);
      }
   }
}

printf(
   "%s %s\n",
   form_bytes($rtdn, "↓"), form_bytes($rtup, "↑")
);

exit(0);
